@@ -247,7 +247,7 @@ stackByTable <- function(filepath, savepath=NA, folder=FALSE, saveUnzippedFiles=
                                                     encoding="UTF-8", keepLeadingZeros=TRUE))
         } else {
           fls <- try(readTableNEON(x, v), silent=T)
-          if(class(fls)=='try-error') {
+          if(inherits(fls, 'try-error')) {
             fls <- suppressWarnings(data.table::fread(x, sep=",", header=TRUE, 
                                                       encoding="UTF-8", keepLeadingZeros=TRUE))
           }
